@@ -1,5 +1,6 @@
 """网络请求"""
 
+import copy
 import logging
 from abc import ABC, abstractmethod
 from collections import defaultdict
@@ -11,9 +12,8 @@ import orjson as json
 from typing_extensions import override
 
 from ..exceptions import CredentialExpiredError, ResponseCodeError, SignInvalidError
-from .common import calc_md5
 from .credential import Credential
-from .session import get_session
+from .session import Session, get_session
 from .sign import sign
 
 _P = ParamSpec("_P")
@@ -36,9 +36,7 @@ def api_request(
     verify: bool = False,
     ignore_code: bool = False,
     process_bool: bool = True,
-    cache_ttl: int | None = None,
-    cacheable: bool = True,
-    exclude_params: list[str] = [],
+    catch_error_code: list[int] | None = None,
 ):
     """API请求"""
 
@@ -52,9 +50,7 @@ def api_request(
             verify=verify,
             ignore_code=ignore_code,
             process_bool=process_bool,
-            cacheable=cacheable,
-            cache_ttl=cache_ttl,
-            exclude_params=exclude_params,
+            catch_error_code=catch_error_code,
         )
 
     return decorator
@@ -80,17 +76,20 @@ class BaseRequest(ABC):
         verify: bool = False,
         ignore_code: bool = False,
     ) -> None:
-        self.session = get_session()
         self._common = common or {}
         self._credential = credential
         self.verify = verify
         self.ignore_code = ignore_code
-        self.cache = self.session._cache
+
+    @property
+    def session(self) -> Session:
+        """获取请求会话"""
+        return get_session()
 
     @property
     def credential(self) -> Credential:
         """获取请求凭证"""
-        return self._credential or (self.session).credential or Credential()
+        return self._credential or self.session.credential or Credential()
 
     @credential.setter
     def credential(self, value: Credential):
@@ -105,16 +104,16 @@ class BaseRequest(ABC):
         return common
 
     @common.setter
-    def commom(self, value: dict[str, Any]):
+    def common(self, value: dict[str, Any]):
         """设置公共参数"""
         self._common = value
 
     def _build_common_params(self, credential: Credential) -> dict[str, Any]:
-        config = (self.session).api_config
+        config = self.session.api_config
         common = {
             "cv": config["version_code"],
             "v": config["version_code"],
-            "QIMEI36": (self.session).qimei,
+            "QIMEI36": self.session.qimei,
         }
         common.update(self.COMMON_DEFAULTS)
         if credential.has_musicid() and credential.has_musickey():
@@ -127,13 +126,21 @@ class BaseRequest(ABC):
             )
         return common
 
-    def _set_cookies(self, credential: Credential):
+    @staticmethod
+    def build_cookies(credential: Credential) -> httpx.Cookies | None:
+        """根据凭证生成 cookies"""
         if credential.has_musicid() and credential.has_musickey():
             cookies = httpx.Cookies()
             cookies.set("uin", str(credential.musicid), domain=".qq.com")
             cookies.set("qqmusic_key", credential.musickey, domain=".qq.com")
             cookies.set("qm_keyst", credential.musickey, domain=".qq.com")
             cookies.set("tmeLoginType", str(credential.login_type), domain=".qq.com")
+            return cookies
+        return None
+
+    def _set_cookies(self, credential: Credential):
+        cookies = self.build_cookies(credential)
+        if cookies:
             self.session.cookies = cookies
 
     @abstractmethod
@@ -186,10 +193,7 @@ class ApiRequest(BaseRequest, Generic[_P, _R]):
         verify: bool = False,
         ignore_code: bool = False,
         process_bool: bool = True,
-        cache_ttl: int | None = None,
-        cacheable: bool = True,
-        exclude_params: list[str] = [],
-        **kwargs,
+        catch_error_code: list[int] | None = None,
     ) -> None:
         super().__init__(common, credential, verify, ignore_code)
         self.module = module
@@ -198,33 +202,14 @@ class ApiRequest(BaseRequest, Generic[_P, _R]):
         self.api_func = api_func
         self.proceduce_bool = process_bool
         self.processor: Callable[[dict[str, Any]], Any] = NO_PROCESSOR
-        self.cacheable = cacheable
-        self.cache_ttl = cache_ttl
-        self.exclude_params = exclude_params
+        self.catch_error_code = catch_error_code or []
 
-    def copy(self) -> "ApiRequest[_P, _R]":
-        """创建当前 ApiRequest 实例的副本"""
-        req = ApiRequest[_P, _R](
-            module=self.module,
-            method=self.method,
-            api_func=self.api_func,
-            params=self.params.copy(),
-            common=self._common.copy(),
-            credential=self.credential,
-            verify=self.verify,
-            ignore_code=self.ignore_code,
-            process_bool=self.proceduce_bool,
-            cacheable=self.cacheable,
-            cache_ttl=self.cache_ttl,
-            exclude_params=self.exclude_params.copy(),
-        )
-        req.processor = self.processor
-        return req
+    def copy(self) -> "ApiRequest[_P, _R]":  # noqa: D102
+        return copy.deepcopy(self)
 
     @override
     def build_request_data(self) -> dict[str, Any]:
-        common = self._build_common_params(self.credential)
-        return {"comm": common, f"{self.module}.{self.method}": self.data}
+        return {"comm": self.common, f"{self.module}.{self.method}": self.data}
 
     @property
     def data(self) -> dict[str, Any]:
@@ -240,15 +225,6 @@ class ApiRequest(BaseRequest, Generic[_P, _R]):
             "param": params,
         }
 
-    def _generate_cache_key(self) -> str:
-        params = self.params.copy()
-        for key in self.exclude_params:
-            params.pop(key, None)
-        if self.credential:
-            params["credential"] = f"{self.credential.musicid}{self.credential.musickey}"
-        sorted_params = json.dumps(params, option=json.OPT_SORT_KEYS)
-        return calc_md5(sorted_params)
-
     @override
     async def _process_response(self, resp: httpx.Response) -> dict[str, Any]:
         """处理响应数据"""
@@ -274,7 +250,7 @@ class ApiRequest(BaseRequest, Generic[_P, _R]):
             code,
         )
 
-        if code == 0:
+        if code == 0 or code in self.catch_error_code:
             return
 
         if code == 2000:
@@ -295,29 +271,27 @@ class ApiRequest(BaseRequest, Generic[_P, _R]):
             instance._common.update(params.pop("common", {}))
             instance.params.update(params)
             instance.processor = processor
-        key = instance._generate_cache_key()
-        if self.session.enable_cache and self.cacheable:
-            if cache_data := await self.cache.get(key):
-                return cache_data
         resp = await instance.request()
         resp = cast(_R, instance.processor(await instance._process_response(resp)))
-        if self.session.enable_cache and self.cacheable:
-            await self.cache.set(key, resp, ttl=self.cache_ttl)
         return resp
 
     def __repr__(self) -> str:
         return f"<ApiRequest {self.module}.{self.method}>"
 
 
-class RequestItem(TypedDict):
-    """请求 Item"""
+TReq = TypeVar("TReq")
+TProc = TypeVar("TProc")
+
+
+class RequestItem(Generic[TReq, TProc], TypedDict):
+    """请求 Item (支持泛型)"""
 
     id: int
     key: str
-    request: ApiRequest
+    request: TReq
     args: tuple[Any, ...]
     kwargs: dict[str, Any]
-    processor: Callable[[dict[str, Any]], Any] | None
+    processor: Callable[[dict[str, Any]], TProc] | None
 
 
 class RequestGroup(BaseRequest):
@@ -346,7 +320,7 @@ class RequestGroup(BaseRequest):
 
         self._requests.append(
             RequestItem(
-                id=len(self._requests) - 1,
+                id=len(self._requests),
                 key=unique_key,
                 request=request,
                 args=args,
@@ -370,8 +344,6 @@ class RequestGroup(BaseRequest):
                     data = req_item["processor"](req_data.get("data", req_data))
                 else:
                     data = req_data.get("data", req_data)
-                if self.session.enable_cache and req.cacheable:
-                    await self.cache.set(req._generate_cache_key(), data, ttl=req.cache_ttl)
                 self._results[req_item["id"]] = data
         except json.JSONDecodeError:
             self._results = [{"data": resp.text}]
@@ -388,35 +360,19 @@ class RequestGroup(BaseRequest):
     @override
     def build_request_data(self):
         """构建请求"""
-        common = self._build_common_params(self.credential)
         merged_data = {req["key"]: req["request"].data for req in self._requests}
-        data = {"comm": common}
+        data = {"comm": self.common}
         data.update(merged_data)
         return data
 
-    async def _get_cache(self):
-        keys = [req["request"]._generate_cache_key() for req in self._requests if req["request"].cacheable]
-        cache = self.cache
-        cache_data = await cache.multi_get(keys)
-        remove_index = []
-        for idx, data in enumerate(cache_data):
-            if data:
-                self._results[idx] = data
-                remove_index.append(idx)
-        self._requests = [req for idx, req in enumerate(self._requests) if idx not in remove_index]
-
     async def _execute(self) -> list[Any]:
         """执行合并请求并返回各请求结果"""
         if not self._requests:
             return []
         self._results = [None] * len(self._requests)
         await self._prepare_request()
-        if self.session.enable_cache:
-            await self._get_cache()
-
         if not self._requests:
             return self._results
-
         resp = await self.request()
         await self._process_response(resp)
         return self._results
